@@ -1,7 +1,9 @@
 """Holds config for dbt-coves."""
 
+import os
+import re
 from pathlib import Path
-from typing import List, Optional
+from typing import Any, Dict, List, Optional
 
 from pydantic import BaseModel
 
@@ -34,6 +36,9 @@ class GenerateSourcesModel(BaseModel):
     templates_folder: Optional[str] = ".dbt_coves/templates"
     metadata: Optional[str] = ""
     no_prompt: Optional[bool] = False
+    flatten_json_fields: Optional[str] = "ask"
+    overwrite_staging_models: Optional[bool] = False
+    skip_model_props: Optional[bool] = False
 
 
 class GenerateMetadataModel(BaseModel):
@@ -45,11 +50,33 @@ class GenerateMetadataModel(BaseModel):
     no_prompt: Optional[bool] = False
 
 
+class GenerateDocsModel(BaseModel):
+    merge_deferred: Optional[bool] = False
+    state: Optional[str] = ""
+    dbt_args: Optional[str] = ""
+
+
+class GenerateAirflowDagsModel(BaseModel):
+    yml_path: Optional[str] = ""
+    dags_path: Optional[str] = ""
+    validate_operators: Optional[bool] = False
+    generators_folder: Optional[str] = "dbt_coves.tasks.generate.airflow_generators"
+    generators_params: Optional[Dict[str, Any]] = {}
+    secrets_path: Optional[str] = ""
+    secrets_manager: Optional[str] = ""
+    secrets_url: Optional[str] = ""
+    secrets_token: Optional[str] = ""
+    secrets_environment: Optional[str] = ""
+    secrets_tags: Optional[str] = ""
+    secrets_key: Optional[str] = ""
+
+
 class GenerateModel(BaseModel):
     sources: Optional[GenerateSourcesModel] = GenerateSourcesModel()
     properties: Optional[GeneratePropertiesModel] = GeneratePropertiesModel()
     metadata: Optional[GenerateMetadataModel] = GenerateMetadataModel()
-    no_prompt: Optional[bool] = False
+    docs: Optional[GenerateDocsModel] = GenerateDocsModel()
+    airflow_dags: Optional[GenerateAirflowDagsModel] = GenerateAirflowDagsModel()
 
 
 class ExtractAirbyteModel(BaseModel):
@@ -73,7 +100,7 @@ class LoadAirbyteModel(BaseModel):
     secrets_manager: Optional[str] = ""
     secrets_url: Optional[str] = ""
     secrets_token: Optional[str] = ""
-    secrets_project: Optional[str] = ""
+    secrets_environment: Optional[str] = ""
     secrets_tags: Optional[List[str]] = []
     secrets_key: Optional[str] = ""
 
@@ -87,7 +114,7 @@ class LoadFivetranModel(BaseModel):
     secrets_manager: Optional[str] = ""
     secrets_url: Optional[str] = ""
     secrets_token: Optional[str] = ""
-    secrets_project: Optional[str] = ""
+    secrets_environment: Optional[str] = ""
     secrets_tags: Optional[List[str]] = []
     secrets_key: Optional[str] = ""
 
@@ -102,22 +129,11 @@ class LoadModel(BaseModel):
     fivetran: Optional[LoadFivetranModel] = LoadFivetranModel()
 
 
-class SetupAllModel(BaseModel):
-    open_ssl_public_key: Optional[bool] = False
-
-
-class SetupSshModel(BaseModel):
-    open_ssl_public_key: Optional[bool] = False
-
-
-class SetupGitModel(BaseModel):
-    no_prompt: Optional[bool] = False
-
-
 class SetupModel(BaseModel):
-    all: Optional[SetupAllModel] = SetupAllModel()
-    ssh: Optional[SetupSshModel] = SetupSshModel()
-    git: Optional[SetupGitModel] = SetupGitModel()
+    no_prompt: Optional[bool] = False
+    quiet: Optional[bool] = False
+    template_url: Optional[str] = "https://github.com/datacoves/setup_template.git"
+    update: Optional[bool] = False
 
 
 class RunDbtModel(BaseModel):
@@ -127,18 +143,47 @@ class RunDbtModel(BaseModel):
     cleanup: Optional[bool] = False
 
 
+class RedshiftDataSyncModel(BaseModel):
+    tables: Optional[List[str]] = []
+
+
+class SnowflakeDataSyncModel(BaseModel):
+    tables: Optional[List[str]] = []
+
+
+class DataSyncModel(BaseModel):
+    redshift: Optional[RedshiftDataSyncModel] = RedshiftDataSyncModel()
+    snowflake: Optional[SnowflakeDataSyncModel] = SnowflakeDataSyncModel()
+
+
+class BlueGreenModel(BaseModel):
+    prod_db_env_var: Optional[str] = ""
+    staging_database: Optional[str] = ""
+    staging_suffix: Optional[str] = ""
+    drop_staging_db_at_start: Optional[bool] = False
+    keep_staging_db_on_success: Optional[bool] = False
+    drop_staging_db_on_failure: Optional[bool] = False
+    dbt_selector: Optional[str] = ""
+    defer: Optional[bool] = False
+    full_refresh: Optional[bool] = False
+
+
 class ConfigModel(BaseModel):
     generate: Optional[GenerateModel] = GenerateModel()
     extract: Optional[ExtractModel] = ExtractModel()
     load: Optional[LoadModel] = LoadModel()
     setup: Optional[SetupModel] = SetupModel()
     dbt: Optional[RunDbtModel] = RunDbtModel()
+    data_sync: Optional[DataSyncModel] = DataSyncModel()
+    disable_tracking: Optional[bool] = False
+    blue_green: Optional[BlueGreenModel] = BlueGreenModel()
 
 
 class DbtCovesConfig:
     """dbt-coves configuration class."""
 
-    DBT_COVES_CONFIG_FILEPATH = ".dbt_coves/config.yml"
+    DBT_COVES_CONFIG_FOLDER = ".dbt_coves"
+    DBT_COVES_CONFIG_FILEPATHS = [".dbt_coves/config.yml", ".dbt_coves/config.yaml"]
     CLI_OVERRIDE_FLAGS = [
         "generate.properties.templates_folder",
         "generate.properties.metadata",
@@ -159,12 +204,30 @@ class DbtCovesConfig:
         "generate.sources.templates_folder",
         "generate.sources.metadata",
         "generate.sources.no_prompt",
+        "generate.sources.flatten_json_fields",
+        "generate.sources.overwrite_staging_models",
+        "generate.sources.skip_model_props",
         "generate.metadata.database",
         "generate.metadata.schemas",
         "generate.metadata.select_relations",
         "generate.metadata.exclude_relations",
         "generate.metadata.destination",
         "generate.metadata.no_prompt",
+        "generate.docs.merge_deferred",
+        "generate.docs.state",
+        "generate.docs.dbt_args",
+        "generate.airflow_dags.yml_path",
+        "generate.airflow_dags.dags_path",
+        "generate.airflow_dags.validate_operators",
+        "generate.airflow_dags.generators_folder",
+        "generate.airflow_dags.generators_params",
+        "generate.airflow_dags.secrets_path",
+        "generate.airflow_dags.secrets_manager",
+        "generate.airflow_dags.secrets_url",
+        "generate.airflow_dags.secrets_token",
+        "generate.airflow_dags.secrets_environment",
+        "generate.airflow_dags.secrets_tags",
+        "generate.airflow_dags.secrets_key",
         "extract.airbyte.path",
         "extract.airbyte.host",
         "extract.airbyte.port",
@@ -175,12 +238,13 @@ class DbtCovesConfig:
         "load.airbyte.secrets_manager",
         "load.airbyte.secrets_url",
         "load.airbyte.secrets_token",
-        "load.airbyte.secrets_project",
+        "load.airbyte.secrets_environment",
         "load.airbyte.secrets_tags",
         "load.airbyte.secrets_key",
-        "setup.all.open_ssl_public_key",
-        "setup.ssh.open_ssl_public_key",
-        "setup.git.no_prompt",
+        "setup.no_prompt",
+        "setup.quiet",
+        "setup.template_url",
+        "setup.update",
         "dbt.command",
         "dbt.project_dir",
         "dbt.virtualenv",
@@ -197,9 +261,20 @@ class DbtCovesConfig:
         "load.fivetran.secrets_manager",
         "load.fivetran.secrets_url",
         "load.fivetran.secrets_token",
-        "load.fivetran.secrets_project",
+        "load.fivetran.secrets_environment",
         "load.fivetran.secrets_tags",
         "load.fivetran.secrets_key",
+        "data_sync.redshift.tables",
+        "data_sync.snowflake.tables",
+        "blue_green.prod_db_env_var",
+        "blue_green.staging_database",
+        "blue_green.staging_suffix",
+        "blue_green.drop_staging_db_at_start",
+        "blue_green.drop_staging_db_on_failure",
+        "blue_green.dbt_selector",
+        "blue_green.defer",
+        "blue_green.full_refresh",
+        "blue_green.keep_staging_db_on_success",
     ]
 
     def __init__(self, flags: DbtCovesFlags) -> None:
@@ -232,13 +307,45 @@ class DbtCovesConfig:
                 target[key] = source[key]
         return config_copy
 
+    @property
+    def disable_tracking(self):
+        return self._config.disable_tracking
+
     def load_and_validate_config_yaml(self) -> None:
         if self._config_path:
             yaml_dict = open_yaml(self._config_path) or {}
 
+            # Replace environment variable placeholders
+            yaml_dict = self.replace_env_vars(yaml_dict)
+
             # use pydantic to shape and validate
             self._config = ConfigModel(**yaml_dict)
 
+    def replace_env_vars(self, yaml_dict: Dict) -> Dict:
+        # regex -> {{ env_var('ENV_VAR_NAME', 'DEFAULT_VALUE') }}
+        env_var_pattern = re.compile(
+            r"\{\{\s*env_var\s*\(\s*['\"]?\s*([^'\"]+)['\"]?\s*(?:,\s*['\"]?\s*([^'\"]+)['\"]?\s*)?\)\s*\}\}"
+        )
+
+        # Iterate through the YAML dictionary and replace placeholders
+        def replace_env_var(match):
+            env_var_name = match.group(1)
+            default_value = match.group(2) or ""
+            return os.environ.get(env_var_name, default_value)
+
+        def replace_recursively(obj):
+            if isinstance(obj, dict):
+                for key, value in obj.items():
+                    obj[key] = replace_recursively(value)
+            elif isinstance(obj, list):
+                for i, item in enumerate(obj):
+                    obj[i] = replace_recursively(item)
+            elif isinstance(obj, str):
+                obj = env_var_pattern.sub(replace_env_var, obj)
+            return obj
+
+        return replace_recursively(yaml_dict)
+
     def validate_dbt_project(self):
         if not self._flags.task_cls.needs_dbt_project:
             return True
@@ -253,11 +360,13 @@ class DbtCovesConfig:
         if self._config_path == Path(str()):
             logger.debug("Trying to find .dbt_coves in current folder")
 
-            config_path = Path().joinpath(self.DBT_COVES_CONFIG_FILEPATH)
-            if config_path.exists():
-                coves_config_dir = config_path
-                logger.debug(f"{coves_config_dir} exists and was retreived.")
-                self._config_path = coves_config_dir
+            for filename in self.DBT_COVES_CONFIG_FILEPATHS:
+                config_path = Path(os.environ.get("DATACOVES__DBT_HOME", "")).joinpath(filename)
+                if config_path.exists():
+                    coves_config_dir = config_path
+                    logger.debug(f"{coves_config_dir} exists and was retrieved.")
+                    self._config_path = coves_config_dir
+                    break
 
     def load_config(self) -> None:
         is_project_valid = self.validate_dbt_project()
