@@ -9,6 +9,7 @@ from rich.console import Console
 from rich.text import Text
 
 from dbt_coves.tasks.base import NonDbtBaseConfiguredTask
+from dbt_coves.utils.tracking import trackable
 
 console = Console()
 
@@ -32,7 +33,7 @@ class RunDbtTask(NonDbtBaseConfiguredTask):
             # help="Run dbt on an isolated environment",
             help="""Use this command to run dbt commands on special environments
             such as Airflow, or CI workers. When a read-write copy needs to be
-            created, its path can be found in DBT_COVES__CLONE_PATH.""",
+            created, its path can be found in /tmp/dbt_coves_dbt_clone_path.txt.""",
         )
         ext_subparser.set_defaults(cls=cls, which="dbt")
         cls.arg_parser = ext_subparser
@@ -57,6 +58,7 @@ class RunDbtTask(NonDbtBaseConfiguredTask):
 
         return ext_subparser
 
+    @trackable
     def run(self) -> int:
         project_dir = self.get_config_value("project_dir")
         if not project_dir:
@@ -67,7 +69,10 @@ class RunDbtTask(NonDbtBaseConfiguredTask):
 
         command = self.get_config_value("command")
         if self.is_readonly(project_dir):
-            tmp_dir = os.environ.get("DBT_COVES__CLONE_PATH")
+            path_file = Path("/tmp/dbt_coves_dbt_clone_path.txt")
+            tmp_dir = None
+            if path_file.exists():
+                tmp_dir = open(path_file).read().rstrip("\n")
             if not tmp_dir:
                 tmp_dir = tempfile.NamedTemporaryFile().name
             if not os.path.exists(tmp_dir):
@@ -82,7 +87,9 @@ class RunDbtTask(NonDbtBaseConfiguredTask):
                     console.print("Removing cloned read-write copy.")
                     shutil.rmtree(tmp_dir, ignore_errors=True)
                 else:
-                    os.environ["DBT_COVES__CLONE_PATH"] = tmp_dir
+                    console.print("Writing dbt clone path to '/tmp/dbt_coves_dbt_clone_path.txt'.")
+                    with open(path_file, "w") as f:
+                        f.write(tmp_dir)
         else:
             self.run_dbt(command, cwd=project_dir)
 
@@ -125,16 +132,15 @@ class RunDbtTask(NonDbtBaseConfiguredTask):
             cmd_list = shlex.split(command)
 
         try:
-            output = subprocess.check_output(cmd_list, env=env, cwd=cwd)
+            output = subprocess.check_output(cmd_list, env=env, cwd=cwd, stderr=subprocess.PIPE)
             console.print(
                 f"{Text.from_ansi(output.decode())}\n"
                 f"[green]{command} :heavy_check_mark:[/green]"
             )
         except subprocess.CalledProcessError as e:
-            raise RunDbtException(
-                f"Exception ocurred running [red]{command}[/red]:\n"
-                f"{Text.from_ansi(e.output.decode())}"
-            )
+            formatted = f"{Text.from_ansi(e.stderr.decode()) if e.stderr else Text.from_ansi(e.stdout.decode())}"
+            e.stderr = f"An error has occurred running [red]{command}[/red]:\n{formatted}"
+            raise
 
     def get_config_value(self, key):
         return self.coves_config.integrated["dbt"][key]
