@@ -2,18 +2,21 @@ import glob
 import json
 import os
 import pathlib
+import re
 from copy import copy
 
 from rich.console import Console
 
+from dbt_coves.core.exceptions import MissingArgumentException
 from dbt_coves.utils.api_caller import AirbyteApiCaller
+from dbt_coves.utils.tracking import trackable
 
 from .base import BaseExtractTask
 
 # from dbt_coves.utils import airbyte_api
 
 console = Console()
-NON_EXTRACT_KEYS = ["icon"]
+NON_EXTRACT_KEYS = ["icon", "breakingChange"]
 
 
 class AirbyteExtractorException(Exception):
@@ -21,6 +24,17 @@ class AirbyteExtractorException(Exception):
 
 
 class ExtractAirbyteTask(BaseExtractTask):
+    def _normalize_filename(self, name: str) -> str:
+        """
+        Normalize a string to be safe for filenames: lowercase, replace spaces and unsafe chars with underscores.
+        """
+        name = name.lower()
+        # Replace spaces and any non-alphanumeric character with underscore
+        name = re.sub(r"[^a-z0-9\-]+", "_", name)
+        # Remove leading/trailing underscores
+        name = name.strip("_")
+        return name
+
     """
     Task that extracts airbyte sources, connections and destinations and stores them as json files
     """
@@ -52,6 +66,7 @@ class ExtractAirbyteTask(BaseExtractTask):
         subparser.set_defaults(cls=cls, which="airbyte")
         return subparser
 
+    @trackable
     def run(self):
         self.extraction_results = {
             "sources": set(),
@@ -64,10 +79,7 @@ class ExtractAirbyteTask(BaseExtractTask):
         airbyte_port = self.get_config_value("port")
 
         if not extract_destination or not airbyte_host or not airbyte_port:
-            raise AirbyteExtractorException(
-                "Couldn't start extraction: one (or more) of the following arguments is missing"
-                "either in the configuration file or Command-Line arguments: 'path', 'host', 'port'"
-            )
+            raise MissingArgumentException(["path", "host", "port"], self.coves_config)
 
         extract_destination = pathlib.Path(extract_destination)
 
@@ -122,7 +134,9 @@ class ExtractAirbyteTask(BaseExtractTask):
             "workspaceId": self.airbyte_api.airbyte_workspace_id,
         }
         return self.airbyte_api.api_call(
-            self.airbyte_api.airbyte_endpoint_get_destination_definition,
+            self.airbyte_api.api_endpoints["GET_OBJECTS"].format(
+                obj="destination_definition_specifications"
+            ),
             req_body,
         )
 
@@ -170,7 +184,10 @@ class ExtractAirbyteTask(BaseExtractTask):
             "workspaceId": self.airbyte_api.airbyte_workspace_id,
         }
         return self.airbyte_api.api_call(
-            self.airbyte_api.airbyte_endpoint_get_source_definition, req_body
+            self.airbyte_api.api_endpoints["GET_OBJECTS"].format(
+                obj="source_definition_specifications"
+            ),
+            req_body,
         )
 
     def _hide_configuration_secret_fields(self, connection_configuration, airbyte_secret_fields):
@@ -232,7 +249,8 @@ class ExtractAirbyteTask(BaseExtractTask):
         )
 
     def _remove_unnecessary_fields(self, json_object):
-        for k in json_object.keys():
+        json_copy = json_object.copy()
+        for k in json_copy.keys():
             if k in NON_EXTRACT_KEYS:
                 del json_object[k]
         return json_object
@@ -242,28 +260,29 @@ class ExtractAirbyteTask(BaseExtractTask):
         try:
             with open(path, "w") as json_file:
                 json.dump(json_object, json_file, indent=4)
+                json_file.write("\n")
         except OSError as e:
             raise AirbyteExtractorException(f"Couldn't write {path}: {e}")
 
-    def _save_json_connection(self, connection):
+    def _save_json_connection(self, connection: dict):
         connection = copy(connection)
         connection.pop("connectionId")
 
-        connection_source_name = self._get_airbyte_source_from_id(connection["sourceId"])[
-            "name"
-        ].lower()
+        connection_source_name = self._get_airbyte_source_from_id(connection["sourceId"])["name"]
         connection_destination_name = self._get_airbyte_destination_from_id(
             connection["destinationId"]
-        )["name"].lower()
+        )["name"]
 
         # Once we used the source and destination IDs,
         # they are no longer required and don't need to be saved
         # Instead, they are replaced with their respective names
         connection.pop("sourceId", None)
         connection.pop("destinationId", None)
+        connection.pop("sourceCatalogId", None)
         connection["sourceName"] = connection_source_name
         connection["destinationName"] = connection_destination_name
         filename = f"{connection_source_name}-{connection_destination_name}.json"
+        filename = self._normalize_filename(filename)
         path = os.path.join(self.connections_extract_destination, filename)
 
         self._save_json(path, connection)
@@ -276,10 +295,11 @@ class ExtractAirbyteTask(BaseExtractTask):
         destination.pop("workspaceId", None)
         destination.pop("destinationId", None)
         filename = f"{destination['name']}.json"
-        path = os.path.join(self.destinations_extract_destination, filename.lower())
+        filename = self._normalize_filename(filename)
+        path = os.path.join(self.destinations_extract_destination, filename)
 
         self._save_json(path, destination)
-        self.extraction_results["destinations"].add(filename.lower())
+        self.extraction_results["destinations"].add(filename)
 
     def _save_json_source(self, source):
         source = copy(source)
@@ -287,10 +307,11 @@ class ExtractAirbyteTask(BaseExtractTask):
         source.pop("workspaceId", None)
         source.pop("sourceId", None)
         filename = f"{source['name']}.json"
-        path = os.path.join(self.sources_extract_destination, filename.lower())
+        filename = self._normalize_filename(filename)
+        path = os.path.join(self.sources_extract_destination, filename)
 
         self._save_json(path, source)
-        self.extraction_results["sources"].add(filename.lower())
+        self.extraction_results["sources"].add(filename)
 
     def get_config_value(self, key):
         return self.coves_config.integrated["extract"]["airbyte"][key]
