@@ -2,6 +2,8 @@ from rich.console import Console
 
 from dbt_coves.tasks.base import BaseConfiguredTask
 
+from .airflow_dags import GenerateAirflowDagsTask
+from .docs import GenerateDocsTask
 from .metadata import GenerateMetadataTask
 from .properties import GeneratePropertiesTask
 from .sources import GenerateSourcesTask
@@ -23,6 +25,8 @@ class GenerateTask(BaseConfiguredTask):
         GenerateSourcesTask,
         GenerateMetadataTask,
         GenerateTemplatesTask,
+        GenerateDocsTask,
+        GenerateAirflowDagsTask,
     ]
 
     @classmethod
@@ -33,12 +37,6 @@ class GenerateTask(BaseConfiguredTask):
             help="""Generates dbt source and staging files, model property files and extracts
              metadata for tables (used as input for sources and properties)""",
         )
-        gen_subparser.add_argument(
-            "--no-prompt",
-            help="Silently generate dbt-coves resources",
-            action="store_true",
-            default=False,
-        )
         gen_subparser.set_defaults(cls=cls, which="generate")
         sub_parsers = gen_subparser.add_subparsers(title="dbt-coves generate commands", dest="task")
 
